/* Copyright (c) 2011, Geert Bergman (geert@scrivo.nl)
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 3. Neither the name of "Scrivo" nor the names of its contributors may be
 *    used to endorse or promote products derived from this software without
 *    specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: SymbolDialog.js 842 2013-08-19 22:54:50Z geert $
 */

//"use strict";

SUI.editor.htmleditor.SymbolDialog = SUI.defineClass(
	/** @lends SUI.editor.htmleditor.SymbolDialog.prototype */{

	/** @ignore */ baseClass: SUI.dialog.OKCancelDialog,

	initializer: function(arg) {

		SUI.editor.htmleditor.SymbolDialog.initializeBase(this, arg);
		var that = this;

		this.caption(
			SUI.editor.i18n.htmleditor.symbolDialog.cptInsertSymbol);

		this.populateForm();
	},

	MARGIN: 8,
	CTRL_HEIGHT: 20,
	LABEL_WIDTH: 80,
	CH_PER_LINE: 21,
	BUTTON_SIZE: 20,
	CHARACTERS: [
		["ISO 8859-1 characters", "\u00A0", "&nbsp;", "&#160;",
			"no-break space = non-breaking space", "U++00A0 ISOnum"],
		["ISO 8859-1 characters", "\u00A1", "&iexcl;", "&#161;",
			"inverted exclamation mark", "U++00A1 ISOnum"],
		["ISO 8859-1 characters", "\u00A2", "&cent;", "&#162;",
			"cent sign", "U++00A2 ISOnum"],
		["ISO 8859-1 characters", "\u00A3", "&pound;", "&#163;",
			"pound sign", "U++00A3 ISOnum"],
		["ISO 8859-1 characters", "\u00A4", "&curren;", "&#164;",
			"currency sign", "U++00A4 ISOnum"],
		["ISO 8859-1 characters", "\u00A5", "&yen;", "&#165;",
			"yen sign = yuan sign", "U++00A5 ISOnum"],
		["ISO 8859-1 characters", "\u00A6", "&brvbar;", "&#166;",
			"broken bar = broken vertical bar", "U++00A6 ISOnum"],
		["ISO 8859-1 characters", "\u00A7", "&sect;", "&#167;",
			"section sign", "U++00A7 ISOnum"],
		["ISO 8859-1 characters", "\u00A8", "&uml;", "&#168;",
			"diaeresis = spacing diaeresis", "U++00A8 ISOdia"],
		["ISO 8859-1 characters", "\u00A9", "&copy;", "&#169;",
			"copyright sign", "U++00A9 ISOnum"],
		["ISO 8859-1 characters", "\u00AA", "&ordf;", "&#170;",
			"feminine ordinal indicator", "U++00AA ISOnum"],
		["ISO 8859-1 characters", "\u00AB", "&laquo;", "&#171;",
			"left-pointing double angle quotation mark = left pointing"
			 + " guillemet",
			"U++00AB ISOnum"],
		["ISO 8859-1 characters", "\u00AC", "&not;", "&#172;",
			"not sign", "U++00AC ISOnum"],
		["ISO 8859-1 characters", "\u00AD", "&shy;", "&#173;",
			"soft hyphen = discretionary hyphen", "U++00AD ISOnum"],
		["ISO 8859-1 characters", "\u00AE", "&reg;", "&#174;",
			"registered sign = registered trade mark sign", "U++00AE ISOnum"],
		["ISO 8859-1 characters", "\u00AF", "&macr;", "&#175;",
			"macron = spacing macron = overline = APL overbar",
			"U++00AF ISOdia"],
		["ISO 8859-1 characters", "\u00B0", "&deg;", "&#176;",
			"degree sign", "U++00B0 ISOnum"],
		["ISO 8859-1 characters", "\u00B1", "&plusmn;", "&#177;",
			"plus-minus sign = plus-or-minus sign", "U++00B1 ISOnum"],
		["ISO 8859-1 characters", "\u00B2", "&sup2;", "&#178;",
			"superscript two = superscript digit two = squared",
			"U++00B2 ISOnum"],
		["ISO 8859-1 characters", "\u00B3", "&sup3;", "&#179;",
			"superscript three = superscript digit three = cubed",
			"U++00B3 ISOnum"],
		["ISO 8859-1 characters", "\u00B4", "&acute;", "&#180;",
			"acute accent = spacing acute", "U++00B4 ISOdia"],
		["ISO 8859-1 characters", "\u00B5", "&micro;", "&#181;",
			"micro sign", "U++00B5 ISOnum"],
		["ISO 8859-1 characters", "\u00B6", "&para;", "&#182;",
			"pilcrow sign = paragraph sign", "U++00B6 ISOnum"],
		["ISO 8859-1 characters", "\u00B7", "&middot;", "&#183;",
			"middle dot = Georgian comma = Greek middle dot",
			"U++00B7 ISOnum"],
		["ISO 8859-1 characters", "\u00B8", "&cedil;", "&#184;",
			"cedilla = spacing cedilla", "U++00B8 ISOdia"],
		["ISO 8859-1 characters", "\u00B9", "&sup1;", "&#185;",
			"superscript one = superscript digit one", "U++00B9 ISOnum"],
		["ISO 8859-1 characters", "\u00BA", "&ordm;", "&#186;",
			"masculine ordinal indicator", "U++00BA ISOnum"],
		["ISO 8859-1 characters", "\u00BB", "&raquo;", "&#187;",
			"right-pointing double angle quotation mark = right pointing"
			 + " guillemet",
			"U++00BB ISOnum"],
		["ISO 8859-1 characters", "\u00BC", "&frac14;", "&#188;",
			"vulgar fraction one quarter = fraction one quarter",
			"U++00BC ISOnum"],
		["ISO 8859-1 characters", "\u00BD", "&frac12;", "&#189;",
			"vulgar fraction one half = fraction one half", "U++00BD ISOnum"],
		["ISO 8859-1 characters", "\u00BE", "&frac34;", "&#190;",
			"vulgar fraction three quarters = fraction three quarters",
			"U++00BE ISOnum"],
		["ISO 8859-1 characters", "\u00BF", "&iquest;", "&#191;",
			"inverted question mark = turned question mark", "U++00BF ISOnum"],
		["ISO 8859-1 characters", "\u00C0", "&Agrave;", "&#192;",
			"latin capital letter A with grave = latin capital letter A grave",
			"U++00C0 ISOlat1"],
		["ISO 8859-1 characters", "\u00C1", "&Aacute;", "&#193;",
			"latin capital letter A with acute", "U++00C1 ISOlat1"],
		["ISO 8859-1 characters", "\u00C2", "&Acirc;", "&#194;",
			"latin capital letter A with circumflex", "U++00C2 ISOlat1"],
		["ISO 8859-1 characters", "\u00C3", "&Atilde;", "&#195;",
			"latin capital letter A with tilde", "U++00C3 ISOlat1"],
		["ISO 8859-1 characters", "\u00C4", "&Auml;", "&#196;",
			"latin capital letter A with diaeresis", "U++00C4 ISOlat1"],
		["ISO 8859-1 characters", "\u00C5", "&Aring;", "&#197;",
			"latin capital letter A with ring above = latin capital letter A"
			 + " ring",
			"U++00C5 ISOlat1"],
		["ISO 8859-1 characters", "\u00C6", "&AElig;", "&#198;",
			"latin capital letter AE = latin capital ligature AE",
			"U++00C6 ISOlat1"],
		["ISO 8859-1 characters", "\u00C7", "&Ccedil;", "&#199;",
			"latin capital letter C with cedilla", "U++00C7 ISOlat1"],
		["ISO 8859-1 characters", "\u00C8", "&Egrave;", "&#200;",
			"latin capital letter E with grave", "U++00C8 ISOlat1"],
		["ISO 8859-1 characters", "\u00C9", "&Eacute;", "&#201;",
			"latin capital letter E with acute", "U++00C9 ISOlat1"],
		["ISO 8859-1 characters", "\u00CA", "&Ecirc;", "&#202;",
			"latin capital letter E with circumflex", "U++00CA ISOlat1"],
		["ISO 8859-1 characters", "\u00CB", "&Euml;", "&#203;",
			"latin capital letter E with diaeresis", "U++00CB ISOlat1"],
		["ISO 8859-1 characters", "\u00CC", "&Igrave;", "&#204;",
			"latin capital letter I with grave", "U++00CC ISOlat1"],
		["ISO 8859-1 characters", "\u00CD", "&Iacute;", "&#205;",
			"latin capital letter I with acute", "U++00CD ISOlat1"],
		["ISO 8859-1 characters", "\u00CE", "&Icirc;", "&#206;",
			"latin capital letter I with circumflex", "U++00CE ISOlat1"],
		["ISO 8859-1 characters", "\u00CF", "&Iuml;", "&#207;",
			"latin capital letter I with diaeresis", "U++00CF ISOlat1"],
		["ISO 8859-1 characters", "\u00D0", "&ETH;", "&#208;",
			"latin capital letter ETH", "U++00D0 ISOlat1"],
		["ISO 8859-1 characters", "\u00D1", "&Ntilde;", "&#209;",
			"latin capital letter N with tilde", "U++00D1 ISOlat1"],
		["ISO 8859-1 characters", "\u00D2", "&Ograve;", "&#210;",
			"latin capital letter O with grave", "U++00D2 ISOlat1"],
		["ISO 8859-1 characters", "\u00D3", "&Oacute;", "&#211;",
			"latin capital letter O with acute", "U++00D3 ISOlat1"],
		["ISO 8859-1 characters", "\u00D4", "&Ocirc;", "&#212;",
			"latin capital letter O with circumflex", "U++00D4 ISOlat1"],
		["ISO 8859-1 characters", "\u00D5", "&Otilde;", "&#213;",
			"latin capital letter O with tilde", "U++00D5 ISOlat1"],
		["ISO 8859-1 characters", "\u00D6", "&Ouml;", "&#214;",
			"latin capital letter O with diaeresis", "U++00D6 ISOlat1"],
		["ISO 8859-1 characters", "\u00D7", "&times;", "&#215;",
			"multiplication sign", "U++00D7 ISOnum"],
		["ISO 8859-1 characters", "\u00D8", "&Oslash;", "&#216;",
			"latin capital letter O with stroke = latin capital letter O"
			 + " slash",
			"U++00D8 ISOlat1"],
		["ISO 8859-1 characters", "\u00D9", "&Ugrave;", "&#217;",
			"latin capital letter U with grave", "U++00D9 ISOlat1"],
		["ISO 8859-1 characters", "\u00DA", "&Uacute;", "&#218;",
			"latin capital letter U with acute", "U++00DA ISOlat1"],
		["ISO 8859-1 characters", "\u00DB", "&Ucirc;", "&#219;",
			"latin capital letter U with circumflex", "U++00DB ISOlat1"],
		["ISO 8859-1 characters", "\u00DC", "&Uuml;", "&#220;",
			"latin capital letter U with diaeresis", "U++00DC ISOlat1"],
		["ISO 8859-1 characters", "\u00DD", "&Yacute;", "&#221;",
			"latin capital letter Y with acute", "U++00DD ISOlat1"],
		["ISO 8859-1 characters", "\u00DE", "&THORN;", "&#222;",
			"latin capital letter THORN", "U++00DE ISOlat1"],
		["ISO 8859-1 characters", "\u00DF", "&szlig;", "&#223;",
			"latin small letter sharp s = ess-zed", "U++00DF ISOlat1"],
		["ISO 8859-1 characters", "\u00E0", "&agrave;", "&#224;",
			"latin small letter a with grave = latin small letter a grave",
			"U++00E0 ISOlat1"],
		["ISO 8859-1 characters", "\u00E1", "&aacute;", "&#225;",
			"latin small letter a with acute", "U++00E1 ISOlat1"],
		["ISO 8859-1 characters", "\u00E2", "&acirc;", "&#226;",
			"latin small letter a with circumflex", "U++00E2 ISOlat1"],
		["ISO 8859-1 characters", "\u00E3", "&atilde;", "&#227;",
			"latin small letter a with tilde", "U++00E3 ISOlat1"],
		["ISO 8859-1 characters", "\u00E4", "&auml;", "&#228;",
			"latin small letter a with diaeresis", "U++00E4 ISOlat1"],
		["ISO 8859-1 characters", "\u00E5", "&aring;", "&#229;",
			"latin small letter a with ring above = latin small letter a ring",
			"U++00E5 ISOlat1"],
		["ISO 8859-1 characters", "\u00E6", "&aelig;", "&#230;",
			"latin small letter ae = latin small ligature ae",
			"U++00E6 ISOlat1"],
		["ISO 8859-1 characters", "\u00E7", "&ccedil;", "&#231;",
			"latin small letter c with cedilla", "U++00E7 ISOlat1"],
		["ISO 8859-1 characters", "\u00E8", "&egrave;", "&#232;",
			"latin small letter e with grave", "U++00E8 ISOlat1"],
		["ISO 8859-1 characters", "\u00E9", "&eacute;", "&#233;",
			"latin small letter e with acute", "U++00E9 ISOlat1"],
		["ISO 8859-1 characters", "\u00EA", "&ecirc;", "&#234;",
			"latin small letter e with circumflex", "U++00EA ISOlat1"],
		["ISO 8859-1 characters", "\u00EB", "&euml;", "&#235;",
			"latin small letter e with diaeresis", "U++00EB ISOlat1"],
		["ISO 8859-1 characters", "\u00EC", "&igrave;", "&#236;",
			"latin small letter i with grave", "U++00EC ISOlat1"],
		["ISO 8859-1 characters", "\u00ED", "&iacute;", "&#237;",
			"latin small letter i with acute", "U++00ED ISOlat1"],
		["ISO 8859-1 characters", "\u00EE", "&icirc;", "&#238;",
			"latin small letter i with circumflex", "U++00EE ISOlat1"],
		["ISO 8859-1 characters", "\u00EF", "&iuml;", "&#239;",
			"latin small letter i with diaeresis", "U++00EF ISOlat1"],
		["ISO 8859-1 characters", "\u00F0", "&eth;", "&#240;",
			"latin small letter eth", "U++00F0 ISOlat1"],
		["ISO 8859-1 characters", "\u00F1", "&ntilde;", "&#241;",
			"latin small letter n with tilde", "U++00F1 ISOlat1"],
		["ISO 8859-1 characters", "\u00F2", "&ograve;", "&#242;",
			"latin small letter o with grave", "U++00F2 ISOlat1"],
		["ISO 8859-1 characters", "\u00F3", "&oacute;", "&#243;",
			"latin small letter o with acute", "U++00F3 ISOlat1"],
		["ISO 8859-1 characters", "\u00F4", "&ocirc;", "&#244;",
			"latin small letter o with circumflex", "U++00F4 ISOlat1"],
		["ISO 8859-1 characters", "\u00F5", "&otilde;", "&#245;",
			"latin small letter o with tilde", "U++00F5 ISOlat1"],
		["ISO 8859-1 characters", "\u00F6", "&ouml;", "&#246;",
			"latin small letter o with diaeresis", "U++00F6 ISOlat1"],
		["ISO 8859-1 characters", "\u00F7", "&divide;", "&#247;",
			"division sign", "U++00F7 ISOnum"],
		["ISO 8859-1 characters", "\u00F8", "&oslash;", "&#248;",
			"latin small letter o with stroke,  = latin small letter o slash",
			"U++00F8 ISOlat1"],
		["ISO 8859-1 characters", "\u00F9", "&ugrave;", "&#249;",
			"latin small letter u with grave", "U++00F9 ISOlat1"],
		["ISO 8859-1 characters", "\u00FA", "&uacute;", "&#250;",
			"latin small letter u with acute", "U++00FA ISOlat1"],
		["ISO 8859-1 characters", "\u00FB", "&ucirc;", "&#251;",
			"latin small letter u with circumflex", "U++00FB ISOlat1"],
		["ISO 8859-1 characters", "\u00FC", "&uuml;", "&#252;",
			"latin small letter u with diaeresis", "U++00FC ISOlat1"],
		["ISO 8859-1 characters", "\u00FD", "&yacute;", "&#253;",
			"latin small letter y with acute", "U++00FD ISOlat1"],
		["ISO 8859-1 characters", "\u00FE", "&thorn;", "&#254;",
			"latin small letter thorn", "U++00FE ISOlat1"],
		["ISO 8859-1 characters", "\u00FF", "&yuml;", "&#255;",
			"latin small letter y with diaeresis", "U++00FF ISOlat1"],
		["Latin Extended-B", "\u0192", "&fnof;", "&#402;",
			"latin small f with hook = function   = florin",
			"U++0192 ISOtech"],
		["General Punctuation", "\u2022", "&bull;", "&#8226;",
			"bullet = black small circle", "U++2022 ISOpub "],
		["General Punctuation", "\u2026", "&hellip;", "&#8230;",
			"horizontal ellipsis = three dot leader", "U++2026 ISOpub "],
		["General Punctuation", "\u2032", "&prime;", "&#8242;",
			"prime = minutes = feet", "U++2032 ISOtech"],
		["General Punctuation", "\u2033", "&Prime;", "&#8243;",
			"double prime = seconds = inches", "U++2033 ISOtech"],
		["General Punctuation", "\u203E", "&oline;", "&#8254;",
			"overline = spacing overscore", "U++203E NEW"],
		["General Punctuation", "\u2044", "&frasl;", "&#8260;",
			"fraction slash", "U++2044 NEW"],
		["Letterlike Symbols", "\u2118", "&weierp;", "&#8472;",
			"script capital P = power set    = Weierstrass p",
			"U++2118 ISOamso"],
		["Letterlike Symbols", "\u2111", "&image;", "&#8465;",
			"blackletter capital I = imaginary part", "U++2111 ISOamso"],
		["Letterlike Symbols", "\u211C", "&real;", "&#8476;",
			"blackletter capital R = real part symbol", "U++211C ISOamso"],
		["Letterlike Symbols", "\u2122", "&trade;", "&#8482;",
			"trade mark sign", "U++2122 ISOnum"],
		["Letterlike Symbols", "\u2135", "&alefsym;", "&#8501;",
			"alef symbol = first transfinite cardinal", "U++2135 NEW"],
		["Arrows", "\u2190", "&larr;", "&#8592;",
			"leftwards arrow", "U++2190 ISOnum"],
		["Arrows", "\u2191", "&uarr;", "&#8593;",
			"upwards arrow", "U++2191 ISOnum"],
		["Arrows", "\u2192", "&rarr;", "&#8594;",
			"rightwards arrow", "U++2192 ISOnum"],
		["Arrows", "\u2193", "&darr;", "&#8595;",
			"downwards arrow", "U++2193 ISOnum"],
		["Arrows", "\u2194", "&harr;", "&#8596;",
			"left right arrow", "U++2194 ISOamsa"],
		["Arrows", "\u21B5", "&crarr;", "&#8629;",
			"downwards arrow with corner leftwards    = carriage return",
			"U++21B5 NEW"],
		["Arrows", "\u21D0", "&lArr;", "&#8656;",
			"leftwards double arrow", "U++21D0 ISOtech"],
		["Arrows", "\u21D1", "&uArr;", "&#8657;",
			"upwards double arrow", "U++21D1 ISOamsa"],
		["Arrows", "\u21D2", "&rArr;", "&#8658;",
			"rightwards double arrow", "U++21D2 ISOtech"],
		["Arrows", "\u21D3", "&dArr;", "&#8659;",
			"downwards double arrow", "U++21D3 ISOamsa"],
		["Arrows", "\u21D4", "&hArr;", "&#8660;",
			"left right double arrow", "U++21D4 ISOamsa"],
		["Geometric Shapes", "\u25CA", "&loz;", "&#9674;",
			"lozenge", "U++25CA ISOpub"],
		["Miscellaneous Symbols", "\u2660", "&spades;", "&#9824;",
			"black spade suit", "U++2660 ISOpub"],
		["Miscellaneous Symbols", "\u2663", "&clubs;", "&#9827;",
			"black club suit = shamrock", "U++2663 ISOpub"],
		["Miscellaneous Symbols", "\u2665", "&hearts;", "&#9829;",
			"black heart suit = valentine", "U++2665 ISOpub"],
		["Miscellaneous Symbols", "\u2666", "&diams;", "&#9830;",
			"black diamond suit", "U++2666 ISOpub"],
		["C0 Controls and Basic Latin", "\u0022", "&quot;", "&#34;",
			"quotation mark = APL quote", "U++0022 ISOnum"],
		["C0 Controls and Basic Latin", "\u0026", "&amp;", "&#38;",
			"ampersand", "U++0026 ISOnum"],
		["C0 Controls and Basic Latin", "\u003C", "&lt;", "&#60;",
			"less-than sign", "U++003C ISOnum"],
		["C0 Controls and Basic Latin", "\u003E", "&gt;", "&#62;",
			"greater-than sign", "U++003E ISOnum"],
		["Latin Extended-A", "\u0152", "&OElig;", "&#338;",
			"latin capital ligature OE", "U++0152 ISOlat2"],
		["Latin Extended-A", "\u0153", "&oelig;", "&#339;",
			"latin small ligature oe", "U++0153 ISOlat2"],
		["Latin Extended-A", "\u0160", "&Scaron;", "&#352;",
			"latin capital letter S with caron", "U++0160 ISOlat2"],
		["Latin Extended-A", "\u0161", "&scaron;", "&#353;",
			"latin small letter s with caron", "U++0161 ISOlat2"],
		["Latin Extended-A", "\u0178", "&Yuml;", "&#376;",
			"latin capital letter Y with diaeresis", "U++0178 ISOlat2"],
		["Spacing Modifier Letters", "\u02C6", "&circ;", "&#710;",
			"modifier letter circumflex accent", "U++02C6 ISOpub"],
		["Spacing Modifier Letters", "\u02DC", "&tilde;", "&#732;",
			"small tilde", "U++02DC ISOdia"],
		["General Punctuation", "\u2002", "&ensp;", "&#8194;",
			"en space", "U++2002 ISOpub"],
		["General Punctuation", "\u2003", "&emsp;", "&#8195;",
			"em space", "U++2003 ISOpub"],
		["General Punctuation", "\u2009", "&thinsp;", "&#8201;",
			"thin space", "U++2009 ISOpub"],
		["General Punctuation", "\u200C", "&zwnj;", "&#8204;",
			"zero width non-joiner", "U++200C NEW RFC 2070"],
		["General Punctuation", "\u200D", "&zwj;", "&#8205;",
			"zero width joiner", "U++200D NEW RFC 2070"],
		["General Punctuation", "\u200E", "&lrm;", "&#8206;",
			"left-to-right mark", "U++200E NEW RFC 2070"],
		["General Punctuation", "\u200F", "&rlm;", "&#8207;",
			"right-to-left mark", "U++200F NEW RFC 2070"],
		["General Punctuation", "\u2013", "&ndash;", "&#8211;",
			"en dash", "U++2013 ISOpub"],
		["General Punctuation", "\u2014", "&mdash;", "&#8212;",
			"em dash", "U++2014 ISOpub"],
		["General Punctuation", "\u2018", "&lsquo;", "&#8216;",
			"left single quotation mark", "U++2018 ISOnum"],
		["General Punctuation", "\u2019", "&rsquo;", "&#8217;",
			"right single quotation mark", "U++2019 ISOnum"],
		["General Punctuation", "\u201A", "&sbquo;", "&#8218;",
			"single low-9 quotation mark", "U++201A NEW"],
		["General Punctuation", "\u201C", "&ldquo;", "&#8220;",
			"left double quotation mark", "U++201C ISOnum"],
		["General Punctuation", "\u201D", "&rdquo;", "&#8221;",
			"right double quotation mark", "U++201D ISOnum"],
		["General Punctuation", "\u201E", "&bdquo;", "&#8222;",
			"double low-9 quotation mark", "U++201E NEW"],
		["General Punctuation", "\u2020", "&dagger;", "&#8224;",
			"dagger", "U++2020 ISOpub"],
		["General Punctuation", "\u2021", "&Dagger;", "&#8225;",
			"double dagger", "U++2021 ISOpub"],
		["General Punctuation", "\u2030", "&permil;", "&#8240;",
			"per mille sign", "U++2030 ISOtech"],
		["General Punctuation", "\u2039", "&lsaquo;", "&#8249;",
			"single left-pointing angle quotation mark",
			"U++2039 ISO proposed"],
		["General Punctuation", "\u203A", "&rsaquo;", "&#8250;",
			"single right-pointing angle quotation mark",
			"U++203A ISO proposed"],
		["General Punctuation", "\u20AC", "&euro;", "&#8364;",
			"euro sign", "U++20AC NEW"],
		["Greek", "\u0391", "&Alpha;", "&#913;",
			"greek capital letter alpha", "U++0391"],
		["Greek", "\u0392", "&Beta;", "&#914;",
			"greek capital letter beta", "U++0392"],
		["Greek", "\u0393", "&Gamma;", "&#915;",
			"greek capital letter gamma", "U++0393 ISOgrk3"],
		["Greek", "\u0394", "&Delta;", "&#916;",
			"greek capital letter delta", "U++0394 ISOgrk3"],
		["Greek", "\u0395", "&Epsilon;", "&#917;",
			"greek capital letter epsilon", "U++0395"],
		["Greek", "\u0396", "&Zeta;", "&#918;",
			"greek capital letter zeta", "U++0396"],
		["Greek", "\u0397", "&Eta;", "&#919;",
			"greek capital letter eta", "U++0397"],
		["Greek", "\u0398", "&Theta;", "&#920;",
			"greek capital letter theta", "U++0398 ISOgrk3"],
		["Greek", "\u0399", "&Iota;", "&#921;",
			"greek capital letter iota", "U++0399"],
		["Greek", "\u039A", "&Kappa;", "&#922;",
			"greek capital letter kappa", "U++039A"],
		["Greek", "\u039B", "&Lambda;", "&#923;",
			"greek capital letter lambda", "U++039B ISOgrk3"],
		["Greek", "\u039C", "&Mu;", "&#924;",
			"greek capital letter mu", "U++039C"],
		["Greek", "\u039D", "&Nu;", "&#925;",
			"greek capital letter nu", "U++039D"],
		["Greek", "\u039E", "&Xi;", "&#926;",
			"greek capital letter xi", "U++039E ISOgrk3"],
		["Greek", "\u039F", "&Omicron;", "&#927;",
			"greek capital letter omicron", "U++039F"],
		["Greek", "\u03A0", "&Pi;", "&#928;",
			"greek capital letter pi", "U++03A0 ISOgrk3"],
		["Greek", "\u03A1", "&Rho;", "&#929;",
			"greek capital letter rho", "U++03A1"],
		["Greek", "\u03A3", "&Sigma;", "&#931;",
			"greek capital letter sigma", "U++03A3 ISOgrk3"],
		["Greek", "\u03A4", "&Tau;", "&#932;",
			"greek capital letter tau", "U++03A4"],
		["Greek", "\u03A5", "&Upsilon;", "&#933;",
			"greek capital letter upsilon", "U++03A5 ISOgrk3"],
		["Greek", "\u03A6", "&Phi;", "&#934;",
			"greek capital letter phi", "U++03A6 ISOgrk3"],
		["Greek", "\u03A7", "&Chi;", "&#935;",
			"greek capital letter chi", "U++03A7"],
		["Greek", "\u03A8", "&Psi;", "&#936;",
			"greek capital letter psi", "U++03A8 ISOgrk3"],
		["Greek", "\u03A9", "&Omega;", "&#937;",
			"greek capital letter omega", "U++03A9 ISOgrk3"],
		["Greek", "\u03B1", "&alpha;", "&#945;",
			"greek small letter alpha", "U++03B1 ISOgrk3"],
		["Greek", "\u03B2", "&beta;", "&#946;",
			"greek small letter beta", "U++03B2 ISOgrk3"],
		["Greek", "\u03B3", "&gamma;", "&#947;",
			"greek small letter gamma", "U++03B3 ISOgrk3"],
		["Greek", "\u03B4", "&delta;", "&#948;",
			"greek small letter delta", "U++03B4 ISOgrk3"],
		["Greek", "\u03B5", "&epsilon;", "&#949;",
			"greek small letter epsilon", "U++03B5 ISOgrk3"],
		["Greek", "\u03B6", "&zeta;", "&#950;",
			"greek small letter zeta", "U++03B6 ISOgrk3"],
		["Greek", "\u03B7", "&eta;", "&#951;",
			"greek small letter eta", "U++03B7 ISOgrk3"],
		["Greek", "\u03B8", "&theta;", "&#952;",
			"greek small letter theta", "U++03B8 ISOgrk3"],
		["Greek", "\u03B9", "&iota;", "&#953;",
			"greek small letter iota", "U++03B9 ISOgrk3"],
		["Greek", "\u03BA", "&kappa;", "&#954;",
			"greek small letter kappa", "U++03BA ISOgrk3"],
		["Greek", "\u03BB", "&lambda;", "&#955;",
			"greek small letter lambda", "U++03BB ISOgrk3"],
		["Greek", "\u03BC", "&mu;", "&#956;",
			"greek small letter mu", "U++03BC ISOgrk3"],
		["Greek", "\u03BD", "&nu;", "&#957;",
			"greek small letter nu", "U++03BD ISOgrk3"],
		["Greek", "\u03BE", "&xi;", "&#958;",
			"greek small letter xi", "U++03BE ISOgrk3"],
		["Greek", "\u03BF", "&omicron;", "&#959;",
			"greek small letter omicron", "U++03BF NEW"],
		["Greek", "\u03C0", "&pi;", "&#960;",
			"greek small letter pi", "U++03C0 ISOgrk3"],
		["Greek", "\u03C1", "&rho;", "&#961;",
			"greek small letter rho", "U++03C1 ISOgrk3"],
		["Greek", "\u03C2", "&sigmaf;", "&#962;",
			"greek small letter final sigma", "U++03C2 ISOgrk3"],
		["Greek", "\u03C3", "&sigma;", "&#963;",
			"greek small letter sigma", "U++03C3 ISOgrk3"],
		["Greek", "\u03C4", "&tau;", "&#964;",
			"greek small letter tau", "U++03C4 ISOgrk3"],
		["Greek", "\u03C5", "&upsilon;", "&#965;",
			"greek small letter upsilon", "U++03C5 ISOgrk3"],
		["Greek", "\u03C6", "&phi;", "&#966;",
			"greek small letter phi", "U++03C6 ISOgrk3"],
		["Greek", "\u03C7", "&chi;", "&#967;",
			"greek small letter chi", "U++03C7 ISOgrk3"],
		["Greek", "\u03C8", "&psi;", "&#968;",
			"greek small letter psi", "U++03C8 ISOgrk3"],
		["Greek", "\u03C9", "&omega;", "&#969;",
			"greek small letter omega", "U++03C9 ISOgrk3"],
		["Greek", "\u03D1", "&thetasym;", "&#977;",
			"greek small letter theta symbol", "U++03D1 NEW"],
		["Greek", "\u03D2", "&upsih;", "&#978;",
			"greek upsilon with hook symbol", "U++03D2 NEW"],
		["Greek", "\u03D6", "&piv;", "&#982;",
			"greek pi symbol", "U++03D6 ISOgrk3"],
		["Mathematical Operators", "\u2200", "&forall;", "&#8704;",
			"for all", "U++2200 ISOtech"],
		["Mathematical Operators", "\u2202", "&part;", "&#8706;",
			"partial differential", "U++2202 ISOtech "],
		["Mathematical Operators", "\u2203", "&exist;", "&#8707;",
			"there exists", "U++2203 ISOtech"],
		["Mathematical Operators", "\u2205", "&empty;", "&#8709;",
			"empty set = null set = diameter", "U++2205 ISOamso"],
		["Mathematical Operators", "\u2207", "&nabla;", "&#8711;",
			"nabla = backward difference", "U++2207 ISOtech"],
		["Mathematical Operators", "\u2208", "&isin;", "&#8712;",
			"element of", "U++2208 ISOtech"],
		["Mathematical Operators", "\u2209", "&notin;", "&#8713;",
			"not an element of", "U++2209 ISOtech"],
		["Mathematical Operators", "\u220B", "&ni;", "&#8715;",
			"contains as member", "U++220B ISOtech"],
		["Mathematical Operators", "\u220F", "&prod;", "&#8719;",
			"n-ary product = product sign", "U++220F ISOamsb"],
		["Mathematical Operators", "\u2211", "&sum;", "&#8721;",
			"n-ary sumation", "U++2211 ISOamsb"],
		["Mathematical Operators", "\u2212", "&minus;", "&#8722;",
			"minus sign", "U++2212 ISOtech"],
		["Mathematical Operators", "\u2217", "&lowast;", "&#8727;",
			"asterisk operator", "U++2217 ISOtech"],
		["Mathematical Operators", "\u221A", "&radic;", "&#8730;",
			"square root = radical sign", "U++221A ISOtech"],
		["Mathematical Operators", "\u221D", "&prop;", "&#8733;",
			"proportional to", "U++221D ISOtech"],
		["Mathematical Operators", "\u221E", "&infin;", "&#8734;",
			"infinity", "U++221E ISOtech"],
		["Mathematical Operators", "\u2220", "&ang;", "&#8736;",
			"angle", "U++2220 ISOamso"],
		["Mathematical Operators", "\u2227", "&and;", "&#8743;",
			"logical and = wedge", "U++2227 ISOtech"],
		["Mathematical Operators", "\u2228", "&or;", "&#8744;",
			"logical or = vee", "U++2228 ISOtech"],
		["Mathematical Operators", "\u2229", "&cap;", "&#8745;",
			"intersection = cap", "U++2229 ISOtech"],
		["Mathematical Operators", "\u222A", "&cup;", "&#8746;",
			"union = cup", "U++222A ISOtech"],
		["Mathematical Operators", "\u222B", "&int;", "&#8747;",
			"integral", "U++222B ISOtech"],
		["Mathematical Operators", "\u2234", "&there4;", "&#8756;",
			"therefore", "U++2234 ISOtech"],
		["Mathematical Operators", "\u223C", "&sim;", "&#8764;",
			"tilde operator = varies with = similar to", "U++223C ISOtech"],
		["Mathematical Operators", "\u2245", "&cong;", "&#8773;",
			"approximately equal to", "U++2245 ISOtech"],
		["Mathematical Operators", "\u2248", "&asymp;", "&#8776;",
			"almost equal to = asymptotic to", "U++2248 ISOamsr"],
		["Mathematical Operators", "\u2260", "&ne;", "&#8800;",
			"not equal to", "U++2260 ISOtech"],
		["Mathematical Operators", "\u2261", "&equiv;", "&#8801;",
			"identical to", "U++2261 ISOtech"],
		["Mathematical Operators", "\u2264", "&le;", "&#8804;",
			"less-than or equal to", "U++2264 ISOtech"],
		["Mathematical Operators", "\u2265", "&ge;", "&#8805;",
			"greater-than or equal to", "U++2265 ISOtech"],
		["Mathematical Operators", "\u2282", "&sub;", "&#8834;",
			"subset of", "U++2282 ISOtech"],
		["Mathematical Operators", "\u2283", "&sup;", "&#8835;",
			"superset of", "U++2283 ISOtech"],
		["Mathematical Operators", "\u2284", "&nsub;", "&#8836;",
			"not a subset of", "U++2284 ISOamsn"],
		["Mathematical Operators", "\u2286", "&sube;", "&#8838;",
			"subset of or equal to", "U++2286 ISOtech"],
		["Mathematical Operators", "\u2287", "&supe;", "&#8839;",
			"superset of or equal to", "U++2287 ISOtech"],
		["Mathematical Operators", "\u2295", "&oplus;", "&#8853;",
			"circled plus = direct sum", "U++2295 ISOamsb"],
		["Mathematical Operators", "\u2297", "&otimes;", "&#8855;",
			"circled times = vector product", "U++2297 ISOamsb"],
		["Mathematical Operators", "\u22A5", "&perp;", "&#8869;",
			"up tack = orthogonal to = perpendicular", "U++22A5 ISOtech"],
		["Mathematical Operators", "\u22C5", "&sdot;", "&#8901;",
			"dot operator", "U++22C5 ISOamsb"],
		["Miscellaneous Technical", "\u2308", "&lceil;", "&#8968;",
			"left ceiling = apl upstile", "U++2308 ISOamsc "],
		["Miscellaneous Technical", "\u2309", "&rceil;", "&#8969;",
			"right ceiling", "U++2309 ISOamsc "],
		["Miscellaneous Technical", "\u230A", "&lfloor;", "&#8970;",
			"left floor = apl downstile", "U++230A ISOamsc "],
		["Miscellaneous Technical", "\u230B", "&rfloor;", "&#8971;",
			"right floor", "U++230B ISOamsc "],
		["Miscellaneous Technical", "\u2329", "&lang;", "&#9001;",
			"left-pointing angle bracket = bra", "U++2329 ISOtech"],
		["Miscellaneous Technical", "\u232A", "&rang;", "&#9002;",
			"right-pointing angle bracket = ket", "U++232A ISOtech"]
	],


	populateForm: function() {

		var that = this;

		this.okButton.el().style.display = "none";

		this.setClientHeight(Math.ceil(this.CHARACTERS.length/this.CH_PER_LINE)
			* this.BUTTON_SIZE);
		this.setClientWidth(this.CH_PER_LINE * this.BUTTON_SIZE);

		for (var i=0; i<this.CHARACTERS.length;i++) {
			var b = new SUI.ToolbarButton({
				parent: this.clientPanel.clientBox(),
				top: Math.floor(i/this.CH_PER_LINE) * this.BUTTON_SIZE,
				left: (i%this.CH_PER_LINE) * this.BUTTON_SIZE,
				width: this.BUTTON_SIZE,
				height: this.BUTTON_SIZE,
				handler: function() {
					that.close();
					that.callListener("onOK", this.el().innerHTML);
				}
			});
			b.el().innerHTML = this.CHARACTERS[i][2];
			b.el().style.textAlign = "center";
			b.el().title = this.CHARACTERS[i][0]+": "+this.CHARACTERS[i][4];

			this.clientPanel.add(b);
		}


	}


});
